Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(312)

Unified Diff: media/gpu/avda_picture_buffer_manager.cc

Issue 2487813002: Remove delayed error posting from AndroidVideoDecodeAccelerator (Closed)
Patch Set: Rebase Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/gpu/android_video_decode_accelerator.cc ('k') | media/gpu/avda_state_provider.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/gpu/avda_picture_buffer_manager.cc
diff --git a/media/gpu/avda_picture_buffer_manager.cc b/media/gpu/avda_picture_buffer_manager.cc
index 4fe59e2df372d18632176cac163cca8cb23aece8..a77de5a1b6cc912f01424b3ad120b7b0b5b18f97 100644
--- a/media/gpu/avda_picture_buffer_manager.cc
+++ b/media/gpu/avda_picture_buffer_manager.cc
@@ -28,16 +28,15 @@
#include "ui/gl/scoped_binders.h"
#include "ui/gl/scoped_make_current.h"
// If !|ptr|, log a message, post an error to |state_provider_|, and
// return an optional value.
-#define RETURN_IF_NULL(ptr, ...) \
- do { \
- if (!(ptr)) { \
- DLOG(ERROR) << "Got null for " << #ptr; \
- state_provider_->PostError(FROM_HERE, \
- VideoDecodeAccelerator::ILLEGAL_STATE); \
- return __VA_ARGS__; \
- } \
+#define RETURN_IF_NULL(ptr, ...) \
+ do { \
+ if (!(ptr)) { \
+ DLOG(ERROR) << "Got null for " << #ptr; \
+ state_provider_->NotifyError(VideoDecodeAccelerator::ILLEGAL_STATE); \
+ return __VA_ARGS__; \
+ } \
} while (0)
namespace media {
« no previous file with comments | « media/gpu/android_video_decode_accelerator.cc ('k') | media/gpu/avda_state_provider.h » ('j') | no next file with comments »
@@ -28,16 +28,15 @@
#include "ui/gl/scoped_binders.h"
#include "ui/gl/scoped_make_current.h"
-// If !|ptr|, log a message, post an error to |state_provider_|, and
+// If !|ptr|, log a message, notify |state_provider_| of the error, and
// return an optional value.

Powered by Google App Engine
This is Rietveld 408576698